# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.08.14
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_issuer_clients_response import ListIssuerClientsResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListIssuerClientsResponse(unittest.TestCase):
    """ListIssuerClientsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListIssuerClientsResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_issuer_clients_response.ListIssuerClientsResponse()  # noqa: E501
        if include_optional :
            return ListIssuerClientsResponse(
                clients = [
                    agilicus_api.models.issuer_client.IssuerClient(
                        id = '123', 
                        issuer_id = '123', 
                        name = '0', 
                        secret = '0', 
                        application = '0', 
                        org_id = '0', 
                        restricted_organisations = ["org-1","org-2"], 
                        organisation_scope = 'here_only', 
                        redirects = [
                            '0'
                            ], 
                        mfa_challenge = 'user_preference', )
                    ], 
                limit = 56
            )
        else :
            return ListIssuerClientsResponse(
                limit = 56,
        )

    def testListIssuerClientsResponse(self):
        """Test ListIssuerClientsResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
