# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2020.08.14
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.permissions_api import PermissionsApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestPermissionsApi(unittest.TestCase):
    """PermissionsApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.permissions_api.PermissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_elevated_user_roles(self):
        """Test case for get_elevated_user_roles

        Get elevated roles for a user  # noqa: E501
        """
        pass

    def test_list_elevated_user_roles(self):
        """Test case for list_elevated_user_roles

        List all elevated users and their roles  # noqa: E501
        """
        pass

    def test_replace_elevated_user_role(self):
        """Test case for replace_elevated_user_role

        Create or update an elevated user role  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
